==> owncloud-9.0.3.tgz: owncloud/apps/files/l10n/hr.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Pohrana nedostupna",
    "Storage invalid" : "Pohrana neispravna",
    "Unknown error" : "Nepoznata pogreška",
    "Unable to set upload directory." : "Postavka učitavanja direktorija nije moguća",
    "Invalid Token" : "Neispravan token",
    "No file was uploaded. Unknown error" : "Nijedna datoteka nije učitana. Pogreška nepoznata.",
    "There is no error, the file uploaded with success" : "Pogreške nema, datoteka uspješno učitana",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Učitana datoteka premašuje maksimalnu dopuštenu veličinu navedenu u php. ini: ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Učitana datoteka premašuje MAX_FILE_SIZE direktivu navedenu u HTML formi",
    "The uploaded file was only partially uploaded" : "Učitana datoteka samo je djelomično učitana",
    "No file was uploaded" : "Nijedna datoteka nije učitana",
    "Missing a temporary folder" : "Nedostaje privremena mapa",
    "Failed to write to disk" : "Zapisivanje na disk nije uspjelo",
    "Not enough storage available" : "Prostor za pohranu nedostatan",
    "The target folder has been moved or deleted." : "Ciljna mapa je premještena ili izbrisana.",
    "Upload failed. Could not find uploaded file" : "Učitavanje neuspješno. Nije emoguće pronaći učitanu dataoteku",
    "Upload failed. Could not get file info." : "Učitavanje neuspješno. Nije moguće dohvatiti informacije o datoteci",
    "Invalid directory." : "Neispravan direktorij",
    "Files" : "Datoteke",
    "All files" : "Sve datoteke",
    "Favorites" : "Favoriti",
    "Home" : "Kuća",
    "Close" : "Zatvorite",
    "Upload cancelled." : "Učitavanje je prekinuto.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nije moguće učitati {filename} jer je ili direktorij ili ima 0 bajta",
    "Total file size {size1} exceeds upload limit {size2}" : "Ukupna veličina datoteke {size1} premašuje ograničenje unosa {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nedovoljno slobodnog prostora, vi učitavate {size1} a samo je {size2} preostalo",
    "Could not get result from server." : "Nemoguće dobiti rezultat od poslužitelja.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Učitavanje datoteke je u tijeku. Napuštanje stranice prekinut će učitavanje.",
    "Actions" : "Radnje",
    "Download" : "Preuzimanje",
    "Rename" : "Preimenujte",
    "Delete" : "Izbrišite",
    "Disconnect storage" : "Isključite pohranu",
    "Unshare" : "Prestanite dijeliti",
    "Details" : "Detalji",
    "Select" : "Selektiraj",
    "Pending" : "Na čekanju",
    "Unable to determine date" : "Nemogucnost odredjivanja datuma",
    "No entries in this folder match '{filter}'" : "Nema zapisa u ovom folderu match '{filter}'",
    "Name" : "Naziv",
    "Size" : "Veličina",
    "Modified" : "Promijenjeno",
    "_%n folder_::_%n folders_" : ["%n mapa","%n mape","%n mapa"],
    "_%n file_::_%n files_" : ["%n datoteka","%n datoteke","%n datoteka"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "You don’t have permission to upload or create files here" : "Ovdje vam nije dopušteno učitavati ili kreirati datoteke",
    "_Uploading %n file_::_Uploading %n files_" : ["Prenosim %n datoteku","Prenosim %n datoteke","Prenosim %n datoteka"],
    "New" : "Novo",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neispravno ime datoteke.",
    "File name cannot be empty." : "Naziv datoteke ne može biti prazan.",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaša je pohrana puna, datoteke više nije moguće ažurirati niti sinkronizirati!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaš prostor za pohranu je skoro pun ({usedSpacePercent}%)",
    "Favorited" : "Favoritovan",
    "Favorite" : "Favorit",
    "Folder" : "Mapa",
    "New folder" : "Nova mapa",
    "Upload" : "Učitavanje",
    "A new file or folder has been <strong>created</strong>" : "Nova datoteka ili nova mapa su <strong>kreirani</strong>",
    "A file or folder has been <strong>changed</strong>" : "Datoteka ili mapa su <strong>promijenjeni</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Datoteka ili mapa su <strong>izbrisani</strong>",
    "A file or folder has been <strong>restored</strong>" : "Datoteka ili direktorij su <strong>vraćeni</strong>",
    "You created %1$s" : "Vi ste kreirali %1$s",
    "%2$s created %1$s" : "%2$s je kreirao %1$s",
    "%1$s was created in a public folder" : "%1$s je kreiran u javnoj mapi",
    "You changed %1$s" : "Promijenili ste %1$s",
    "%2$s changed %1$s" : "%2$s je promijenio %1$s",
    "You deleted %1$s" : "Izbrisali ste %1$s",
    "%2$s deleted %1$s" : "%2$s je izbrisao %1$s",
    "You restored %1$s" : "Vraćeno %1$s",
    "%2$s restored %1$s" : "%2$s vraćeno %1$s",
    "Upload (max. %s)" : "Prijenos (max. %s)",
    "File handling" : "Obrada datoteke",
    "Maximum upload size" : "Maksimalna veličina učitanog sadržaja",
    "max. possible: " : "max. moguće: ",
    "Save" : "Spremite",
    "Settings" : "Postavke",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Koristitet slijedeću adresu za <a href=\"%s\" target=\"_blank\">pristup vašim datotekama putem WebDAV-a</a>",
    "Cancel upload" : "Prekini upload",
    "Upload some content or sync with your devices!" : "Aplodujte neki sadrzaj ili sinkronizirajte sa vasim uredjajem!",
    "No entries found in this folder" : "Zapis nije pronadjen u ovom direktorijumu ",
    "Select all" : "Selektiraj sve",
    "Upload too large" : "Unos je prevelik",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke koje pokušavate učitati premašuju maksimalnu veličinu za unos datoteka na ovom poslužitelju.",
    "No favorites" : "Nema favorita",
    "Files and folders you mark as favorite will show up here" : "Fajlovi i folderi koje oznacite kao favorite ce se prikazati ovdje",
    "Text file" : "Tekstualna datoteka",
    "You changed %1$s" : "Promijenili ste %1$s",
    "You created %1$s" : "Vi ste kreirali %1$s",
    "You deleted %1$s" : "Izbrisali ste %1$s",
    "You restored %1$s" : "Vraćeno %1$s"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> owncloud-10.0.7.tgz: owncloud/apps/files/l10n/hr.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Pohrana neispravna",
    "Unknown error" : "Nepoznata pogreška",
    "All files" : "Sve datoteke",
    "Saved" : "Spremljeno",
    "Home" : "Kuća",
    "Close" : "Zatvorite",
    "Favorites" : "Favoriti",
    "Upload cancelled." : "Učitavanje je prekinuto.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nije moguće učitati {filename} jer je ili direktorij ili ima 0 bajta",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nedovoljno slobodnog prostora, vi učitavate {size1} a samo je {size2} preostalo",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Učitavanje datoteke je u tijeku. Napuštanje stranice prekinut će učitavanje.",
    "Actions" : "Radnje",
    "Download" : "Preuzimanje",
    "Rename" : "Preimenujte",
    "Delete" : "Izbrišite",
    "Disconnect storage" : "Isključite pohranu",
    "Unshare" : "Prestanite dijeliti",
    "Files" : "Datoteke",
    "Details" : "Detalji",
    "Select" : "Selektiraj",
    "Pending" : "Na čekanju",
    "Unable to determine date" : "Nemogucnost odredjivanja datuma",
    "Invalid path" : "Pogrešna putanja",
    "Name" : "Naziv",
    "Size" : "Veličina",
    "Modified" : "Promijenjeno",
    "_%n folder_::_%n folders_" : ["%n mapa","%n mape","%n mapa"],
    "_%n file_::_%n files_" : ["%n datoteka","%n datoteke","%n datoteka"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "You don’t have permission to upload or create files here" : "Ovdje vam nije dopušteno učitavati ili kreirati datoteke",
    "_Uploading %n file_::_Uploading %n files_" : ["Prenosim %n datoteku","Prenosim %n datoteke","Prenosim %n datoteka"],
    "New" : "Novo",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neispravno ime datoteke.",
    "File name cannot be empty." : "Naziv datoteke ne može biti prazan.",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaša je pohrana puna, datoteke više nije moguće ažurirati niti sinkronizirati!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaš prostor za pohranu je skoro pun ({usedSpacePercent}%)",
    "Favorited" : "Favoritovan",
    "Favorite" : "Favorit",
    "Folder" : "Mapa",
    "New folder" : "Nova mapa",
    "Upload" : "Učitavanje",
    "A new file or folder has been <strong>created</strong>" : "Nova datoteka ili nova mapa su <strong>kreirani</strong>",
    "A file or folder has been <strong>changed</strong>" : "Datoteka ili mapa su <strong>promijenjeni</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Datoteka ili mapa su <strong>izbrisani</strong>",
    "A file or folder has been <strong>restored</strong>" : "Datoteka ili direktorij su <strong>vraćeni</strong>",
    "You created %1$s" : "Vi ste kreirali %1$s",
    "%2$s created %1$s" : "%2$s je kreirao %1$s",
    "%1$s was created in a public folder" : "%1$s je kreiran u javnoj mapi",
    "You changed %1$s" : "Promijenili ste %1$s",
    "%2$s changed %1$s" : "%2$s je promijenio %1$s",
    "You deleted %1$s" : "Izbrisali ste %1$s",
    "%2$s deleted %1$s" : "%2$s je izbrisao %1$s",
    "You restored %1$s" : "Vraćeno %1$s",
    "%2$s restored %1$s" : "%2$s vraćeno %1$s",
    "Upload (max. %s)" : "Prijenos (max. %s)",
    "File handling" : "Obrada datoteke",
    "Maximum upload size" : "Maksimalna veličina učitanog sadržaja",
    "max. possible: " : "max. moguće: ",
    "Save" : "Spremite",
    "Settings" : "Postavke",
    "WebDAV" : "WebDAV",
    "Upload some content or sync with your devices!" : "Aplodujte neki sadrzaj ili sinkronizirajte sa vasim uredjajem!",
    "No entries found in this folder" : "Zapis nije pronadjen u ovom direktorijumu ",
    "Select all" : "Selektiraj sve",
    "Upload too large" : "Unos je prevelik",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke koje pokušavate učitati premašuju maksimalnu veličinu za unos datoteka na ovom poslužitelju.",
    "No favorites" : "Nema favorita",
    "Files and folders you mark as favorite will show up here" : "Fajlovi i folderi koje oznacite kao favorite ce se prikazati ovdje",
    "Text file" : "Tekstualna datoteka"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
